@@ -8,6 +8,7 @@ import pandas as pd
 from palettable.colorbrewer.qualitative import Dark2_8
 from scipy.special import softmax
 
+from puma.utils.discriminant import calc_disc, calc_disc_b, calc_disc_c
 from puma.utils.generate import get_dummy_2_taggers, get_dummy_multiclass_scores
 from puma.utils.logging import logger, set_log_level  # noqa: F401
 
@@ -276,6 +277,22 @@ global_config = {
             "colour": "#e76f51",
             "legend_label": "\u03C4's in $b$- or $c$-hadron decay",
         },
+        "Hbb": {
+            "colour": "#1f77b4",  # blue
+            "legend_label": "$Hbb$-jets",
+        },
+        "Hcc": {
+            "colour": "#B45F06",  # Tenne (dark orange)
+            "legend_label": "$Hcc$-jets",
+        },
+        "top": {
+            "colour": "#A300A3",  # dark magenta
+            "legend_label": "$Top$-jets",
+        },
+        "dijets": {
+            "colour": "#38761D",  # Bilbao (dark green)
+            "legend_label": "light-dijets",
+        },
     },
     "hist_err_style": {
         "fill": False,
